@@ -38,12 +38,11 @@ print_tmap <- function(x, vp=NULL, return.asp=FALSE, mode=getOption("tmap.mode")
 	###################################################################################################################
 	
 	if (proxy) {
-		layerIds <- if ("layerIdsNew" %in% ls(envir = .TMAP_CACHE)) {
-			get("layerIdsNew", envir = .TMAP_CACHE)
-		} else {
-			get("layerIds", envir = .TMAP_CACHE)
-		}
-		assign("layerIds", layerIds, envir = .TMAP_CACHE)
+		#print("proxy")
+		
+		#return(lf %>% leaflet::removeShape(World$iso_a3))
+		
+		layerIds = get("layerIds", envir = .TMAP_CACHE)
 
 		overlays <- get("overlays", envir = .TMAP_CACHE)
 		overlays_tiles <- get("overlays_tiles", envir = .TMAP_CACHE)
@@ -60,12 +59,19 @@ print_tmap <- function(x, vp=NULL, return.asp=FALSE, mode=getOption("tmap.mode")
 				name <- paneName(z)
 				legend <- legendName(z)
 				
-				if (typesList[[name]] == "raster") {
-					lf <- lf %>% leaflet::removeImage(sort(unname(layerIds[[name]]))) %>%
-						leaflet::removeControl(legend)
-				} else {
-					lf <- lf %>% leaflet::removeShape(sort(unname(layerIds[[name]]))) %>%
-						leaflet::removeControl(legend)
+				#print(layerIds[[name]])
+				#print(typesList[[name]])
+				if (!is.null(typesList[[name]])) {
+					if (typesList[[name]] == "raster") {
+						lf <- lf %>% leaflet::removeImage(sort(unname(layerIds[[name]]))) %>%
+							leaflet::removeControl(legend)
+					} else if (typesList[[name]] %in% c("text")) {
+						lf <- lf %>% leaflet::removeMarker(sort(unname(layerIds[[name]]))) %>%
+							leaflet::removeControl(legend)
+					} else {
+						lf <- lf %>% leaflet::removeShape(sort(unname(layerIds[[name]]))) %>%
+							leaflet::removeControl(legend)
+					}
 				}
 				
 				layerIds[[name]] <- NULL
@@ -241,7 +247,8 @@ print_tmap <- function(x, vp=NULL, return.asp=FALSE, mode=getOption("tmap.mode")
 		}
 		lf <- if (nx==1) lfs[[1]] else lfmv <- do.call(leafsync::latticeView, c(lfs, lVargs))
 		
-		lf2 <- if (interactive_titles) view_add_leaflet_titles(lf) else lf
+		#lf2 <- if (interactive_titles) view_add_leaflet_titles(lf) else lf
+		lf2 = lf
 		
 		if (show) {
 			save_last_map()
