@@ -15,13 +15,6 @@ check_raster_specials <- function(x, g, gt, shpcols, data, nx) {
 		is.colors <- FALSE
 		nx <- 1
 	} else {
-		#x <- g$col
-		
-		# if (attr(data, "treat_as_by")) {
-		# 	if (!is.na(x)) warning("col specification in tm_raster is ignored, since stars object contains a 3rd dimension, where its values are used to create facets", call. = FALSE)
-		# 	x <- NA
-		# }
-		
 		# by default, use the all data variables
 		if (is.na(x[1])) {
 			if (nlevels(data$GROUP_BY) > 1) {
@@ -34,7 +27,7 @@ check_raster_specials <- function(x, g, gt, shpcols, data, nx) {
 		
 		## general 'by' check: if by => |aes| = 1, and determine nx
 		if (nlevels(by)>1 && length(x) > 1) {
-			warning("When by is specified (tm_facets), only one value can be assigned to each aesthetic.", call. = FALSE)
+			if (gt$show.warnings) warning("When by is specified (tm_facets), only one value can be assigned to each aesthetic.", call. = FALSE)
 			x <- x[1]
 		}
 		nx <- length(x)
